@@ -40,8 +40,10 @@ class ApplicationProfile(object):
         Returns:
             home_filepath, mackup_filepath (str, str)
         """
-        return (os.path.join(os.environ['HOME'], filename),
-                os.path.join(self.mackup.mackup_folder, filename))
+        return (
+            os.path.join(os.environ["HOME"], filename),
+            os.path.join(self.mackup.mackup_folder, filename),
+        )
 
     def backup(self):
         """
@@ -65,17 +67,18 @@ class ApplicationProfile(object):
             (home_filepath, mackup_filepath) = self.getFilepaths(filename)
 
             # If the file exists and is not already a link pointing to Mackup
-            if ((os.path.isfile(home_filepath) or
-                 os.path.isdir(home_filepath)) and
-                not (os.path.islink(home_filepath) and
-                     (os.path.isfile(mackup_filepath) or
-                      os.path.isdir(mackup_filepath)) and
-                     os.path.samefile(home_filepath,
-                                      mackup_filepath))):
+            if (os.path.isfile(home_filepath) or os.path.isdir(home_filepath)) and not (
+                os.path.islink(home_filepath)
+                and (os.path.isfile(mackup_filepath) or os.path.isdir(mackup_filepath))
+                and os.path.samefile(home_filepath, mackup_filepath)
+            ):
 
                 if self.verbose:
-                    print("Backing up\n  {}\n  to\n  {} ..."
-                          .format(home_filepath, mackup_filepath))
+                    print(
+                        "Backing up\n  {}\n  to\n  {} ...".format(
+                            home_filepath, mackup_filepath
+                        )
+                    )
                 else:
                     print("Backing up {} ...".format(filename))
 
@@ -87,20 +90,20 @@ class ApplicationProfile(object):
 
                     # Name it right
                     if os.path.isfile(mackup_filepath):
-                        file_type = 'file'
+                        file_type = "file"
                     elif os.path.isdir(mackup_filepath):
-                        file_type = 'folder'
+                        file_type = "folder"
                     elif os.path.islink(mackup_filepath):
-                        file_type = 'link'
+                        file_type = "link"
                     else:
-                        raise ValueError("Unsupported file: {}"
-                                         .format(mackup_filepath))
+                        raise ValueError("Unsupported file: {}".format(mackup_filepath))
 
                     # Ask the user if he really want to replace it
-                    if utils.confirm("A {} named {} already exists in the"
-                                     " backup.\nAre you sure that you want to"
-                                     " replace it ?"
-                                     .format(file_type, mackup_filepath)):
+                    if utils.confirm(
+                        "A {} named {} already exists in the"
+                        " backup.\nAre you sure that you want to"
+                        " replace it ?".format(file_type, mackup_filepath)
+                    ):
                         # Delete the file in Mackup
                         utils.delete(mackup_filepath)
                         # Copy the file
@@ -118,16 +121,21 @@ class ApplicationProfile(object):
                     utils.link(mackup_filepath, home_filepath)
             elif self.verbose:
                 if os.path.exists(home_filepath):
-                    print("Doing nothing\n  {}\n  "
-                          "is already backed up to\n  {}"
-                          .format(home_filepath, mackup_filepath))
+                    print(
+                        "Doing nothing\n  {}\n  "
+                        "is already backed up to\n  {}".format(
+                            home_filepath, mackup_filepath
+                        )
+                    )
                 elif os.path.islink(home_filepath):
-                    print("Doing nothing\n  {}\n  "
-                          "is a broken link, you might want to fix it."
-                          .format(home_filepath))
+                    print(
+                        "Doing nothing\n  {}\n  "
+                        "is a broken link, you might want to fix it.".format(
+                            home_filepath
+                        )
+                    )
                 else:
-                    print("Doing nothing\n  {}\n  does not exist"
-                          .format(home_filepath))
+                    print("Doing nothing\n  {}\n  does not exist".format(home_filepath))
 
     def restore(self):
         """
@@ -150,18 +158,23 @@ class ApplicationProfile(object):
             # If the file exists and is not already pointing to the mackup file
             # and the folder makes sense on the current platform (Don't sync
             # any subfolder of ~/Library on GNU/Linux)
-            file_or_dir_exists = (os.path.isfile(mackup_filepath) or
-                                  os.path.isdir(mackup_filepath))
-            pointing_to_mackup = (os.path.islink(home_filepath) and
-                                  os.path.exists(mackup_filepath) and
-                                  os.path.samefile(mackup_filepath,
-                                                   home_filepath))
+            file_or_dir_exists = os.path.isfile(mackup_filepath) or os.path.isdir(
+                mackup_filepath
+            )
+            pointing_to_mackup = (
+                os.path.islink(home_filepath)
+                and os.path.exists(mackup_filepath)
+                and os.path.samefile(mackup_filepath, home_filepath)
+            )
             supported = utils.can_file_be_synced_on_current_platform(filename)
 
             if file_or_dir_exists and not pointing_to_mackup and supported:
                 if self.verbose:
-                    print("Restoring\n  linking {}\n  to      {} ..."
-                          .format(home_filepath, mackup_filepath))
+                    print(
+                        "Restoring\n  linking {}\n  to      {} ...".format(
+                            home_filepath, mackup_filepath
+                        )
+                    )
                 else:
                     print("Restoring {} ...".format(filename))
 
@@ -172,34 +185,41 @@ class ApplicationProfile(object):
                 if os.path.exists(home_filepath):
                     # Name it right
                     if os.path.isfile(home_filepath):
-                        file_type = 'file'
+                        file_type = "file"
                     elif os.path.isdir(home_filepath):
-                        file_type = 'folder'
+                        file_type = "folder"
                     elif os.path.islink(home_filepath):
-                        file_type = 'link'
+                        file_type = "link"
                     else:
-                        raise ValueError("Unsupported file: {}"
-                                         .format(mackup_filepath))
+                        raise ValueError("Unsupported file: {}".format(mackup_filepath))
 
-                    if utils.confirm("You already have a {} named {} in your"
-                                     " home.\nDo you want to replace it with"
-                                     " your backup ?"
-                                     .format(file_type, filename)):
+                    if utils.confirm(
+                        "You already have a {} named {} in your"
+                        " home.\nDo you want to replace it with"
+                        " your backup ?".format(file_type, filename)
+                    ):
                         utils.delete(home_filepath)
                         utils.link(mackup_filepath, home_filepath)
                 else:
                     utils.link(mackup_filepath, home_filepath)
             elif self.verbose:
                 if os.path.exists(home_filepath):
-                    print("Doing nothing\n  {}\n  already linked by\n  {}"
-                          .format(mackup_filepath, home_filepath))
+                    print(
+                        "Doing nothing\n  {}\n  already linked by\n  {}".format(
+                            mackup_filepath, home_filepath
+                        )
+                    )
                 elif os.path.islink(home_filepath):
-                    print("Doing nothing\n  {}\n  "
-                          "is a broken link, you might want to fix it."
-                          .format(home_filepath))
+                    print(
+                        "Doing nothing\n  {}\n  "
+                        "is a broken link, you might want to fix it.".format(
+                            home_filepath
+                        )
+                    )
                 else:
-                    print("Doing nothing\n  {}\n  does not exist"
-                          .format(mackup_filepath))
+                    print(
+                        "Doing nothing\n  {}\n  does not exist".format(mackup_filepath)
+                    )
 
     def uninstall(self):
         """
@@ -221,13 +241,15 @@ class ApplicationProfile(object):
             (home_filepath, mackup_filepath) = self.getFilepaths(filename)
 
             # If the mackup file exists
-            if (os.path.isfile(mackup_filepath) or
-                    os.path.isdir(mackup_filepath)):
+            if os.path.isfile(mackup_filepath) or os.path.isdir(mackup_filepath):
                 # Check if there is a corresponding file in the home folder
                 if os.path.exists(home_filepath):
                     if self.verbose:
-                        print("Reverting {}\n  at {} ..."
-                              .format(mackup_filepath, home_filepath))
+                        print(
+                            "Reverting {}\n  at {} ...".format(
+                                mackup_filepath, home_filepath
+                            )
+                        )
                     else:
                         print("Reverting {} ...".format(filename))
 
@@ -241,5 +263,4 @@ class ApplicationProfile(object):
                     # Copy the Dropbox file to the home folder
                     utils.copy(mackup_filepath, home_filepath)
             elif self.verbose:
-                print("Doing nothing, {} does not exist"
-                      .format(mackup_filepath))
+                print("Doing nothing, {} does not exist".format(mackup_filepath))
